@@ -25,25 +25,24 @@ class Team(object):
         if 'valuesByStat' in data:
             self.stats = {STATS_MAP[i]: j for i, j in data['valuesByStat'].items()}
         if member:
-            self.owner = "%s %s" % (member['firstName'],
-                                    member['lastName'])
+            self.owner = f"{member['firstName']} {member['lastName']}"
         if 'logo' in data:    
             self.logo_url = data['logo']
         
-        self._fetch_roster(roster)
+        self._fetch_roster(roster, year)
         self._fetch_schedule(schedule)
         
     def __repr__(self):
-        return 'Team(%s)' % (self.team_name, )
+        return f'Team({self.team_name})'
     
 
-    def _fetch_roster(self, data):
+    def _fetch_roster(self, data, year):
         '''Fetch teams roster'''
         self.roster.clear()
         roster = data['entries']
 
         for player in roster:
-            self.roster.append(Player(player))
+            self.roster.append(Player(player, year))
 
 
     def _fetch_schedule(self, data):
@@ -58,6 +57,3 @@ class Team(object):
                     new_match = Matchup(match)
                     setattr(new_match, 'home_team', self)
                     self.schedule.append(new_match)
-                    
-        
-                    
